Breaking change detection between two versions of code
Compares symbols between git refs to detect API breaking changes such as removed symbols, signature changes, visibility changes, etc.
Structs
- Breaking
Change Detector - Detects breaking changes between two versions
Functions
- detect_
breaking_ changes - Convenience function to detect breaking changes between file sets