Module breaking_changes

Module breaking_changes 

Breaking change detection between two versions of code

Compares symbols between git refs to detect API breaking changes such as removed symbols, signature changes, visibility changes, etc.

Structs

BreakingChangeDetector
Detects breaking changes between two versions

Functions

detect_breaking_changes
Convenience function to detect breaking changes between file sets